package de.intevation.flys.exports;

import java.awt.Color;

import org.apache.log4j.Logger;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.chart.plot.XYPlot;

/**
 * A ChartInfoGenerator that generates meta information for specific discharge
 * longitudinal section curves.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class DischargeLongitudinalSectionInfoGenerator
extends      ChartInfoGenerator
{
    private static Logger logger =
        Logger.getLogger(DischargeLongitudinalSectionInfoGenerator.class);


    public DischargeLongitudinalSectionInfoGenerator() {
        super(new DischargeLongitudinalSectionGenerator());
    }


    protected int[] getSize() {
        DischargeLongitudinalSectionGenerator gen =
            (DischargeLongitudinalSectionGenerator) generator;

        return gen.getSize();
    }


    /**
     * Creates a chart object.
     *
     * @return a chart object.
     */
    protected JFreeChart generateChart() {
        logger.debug("DischargeCurveInfoGenerator.generateChart");

        DischargeLongitudinalSectionGenerator gen =
            (DischargeLongitudinalSectionGenerator) generator;

        JFreeChart chart = ChartFactory.createXYLineChart(
            gen.getChartTitle(),
            gen.getXAxisLabel(),
            gen.getYAxisLabel(),
            null,
            PlotOrientation.VERTICAL,
            true,
            false,
            false);

        chart.setBackgroundPaint(Color.WHITE);
        chart.getPlot().setBackgroundPaint(Color.WHITE);

        XYPlot plot = (XYPlot) chart.getPlot();

        gen.addDatasets(chart);
        gen.addSubtitles(chart);
        gen.adjustPlot(plot);
        gen.adjustAxes(plot);

        return chart;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
